package org.kantega.jexmec;

/*
 * Copyright 2011 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.Set;

/**
 * Interface responsible for locating service implementations for {@link ServiceKey}s.
 * Implementations will typically look up services from an application managed IoC container
 * like Spring or Guice.
 */
public interface ServiceLocator {

    /**
     * Returns a set of ServiceKeys for the services available in this ServiceLocator.
     *
     * @return the set of available ServiceKeys
     */
    Set<ServiceKey> getServiceKeys();

    /**
     * Look up a service implementation for a service key.
     * @param serviceKey the service key to find an implementation for
     * @return an implementation of the service
     */
    <T> T lookupService(ServiceKey<T> serviceKey);
}
